;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "gnosis" "0.10.4"
  "Knowledge System."
  '((emacs        "29.1")
    (compat       "29.1.4.2")
    (keymap-popup "0.2.0"))
  :url "https://thanosapollo.org/projects/gnosis"
  :commit "952a718b0ae7c1af0992cbc5aa80e1184999aa8a"
  :revdesc "952a718b0ae7"
  :keywords '("extensions")
  :authors '(("Thanos Apollo" . "public@thanosapollo.org"))
  :maintainers '(("Thanos Apollo" . "public@thanosapollo.org")))
